Crate kona_sources

kona-sources

CI kona-sources crate MIT License Docs

Data source types and utilities for the kona-node.

Structs

ClientCert
Client certificate and key pair for mTLS authentication (PEM format)
L2ForkchoiceState
An unsafe, safe, and finalized L2BlockInfo returned by the crate::find_starting_forkchoice function.
Metrics
Container for metrics.
RemoteSigner
Configuration for the remote signer client
RemoteSignerHandler
Remote signer that communicates with an external signing service via JSON-RPC
RuntimeConfig
The runtime config.
RuntimeLoader
The runtime loader.

Enums

BlockSigner
A builder for a block signer.
BlockSignerError
Errors that can occur when signing a block.
BlockSignerHandler
A handler for a block signer.
BlockSignerStartError
Errors that can occur when starting a block signer.
CertificateError
Errors that can occur when handling certificates
RemoteSignerError
Errors that can occur when using the remote signer
RemoteSignerStartError
Errors that can occur when starting a remote signer.
RuntimeLoaderError
Error type for the runtime loader.
SyncStartError
An error that can occur during the sync start process.

Functions

find_starting_forkchoice
Searches for the latest L2ForkchoiceState that we can use to start the sync process with.