pub enum BlockSigner {
Local(PrivateKeySigner),
Remote(RemoteSigner),
}Expand description
A builder for a block signer.
Variants
Local(PrivateKeySigner)
A local block signer that is used to sign blocks with a locally available private key.
Remote(RemoteSigner)
A remote block signer that is used to sign blocks with a remote private key.
Implementations
Sourceimpl BlockSigner
impl BlockSigner
Sourcepub async fn start(self) -> Result<BlockSignerHandler, BlockSignerStartError>
pub async fn start(self) -> Result<BlockSignerHandler, BlockSignerStartError>
Starts a block signer.