pub enum BlockSignerError {
Local(Error),
Remote(RemoteSignerError),
}Expand description
Errors that can occur when signing a block.
Variants
Local(Error)
An error that can occur when signing a block with a local signer.
Remote(RemoteSignerError)
An error that can occur when signing a block with a remote signer.