pub enum BlockSignerHandler {
Local(PrivateKeySigner),
Remote(RemoteSignerHandler),
}Expand description
A handler for a block signer.
Variants
Local(PrivateKeySigner)
A local block signer that is used to sign blocks with a locally available private key.
Remote(RemoteSignerHandler)
A remote block signer that is used to sign blocks with a remote private key.
Implementations
Sourceimpl BlockSignerHandler
impl BlockSignerHandler
Sourcepub async fn sign_block(
&self,
payload_hash: PayloadHash,
chain_id: ChainId,
sender_address: Address,
) -> Result<Signature, BlockSignerError>
pub async fn sign_block( &self, payload_hash: PayloadHash, chain_id: ChainId, sender_address: Address, ) -> Result<Signature, BlockSignerError>
Signs a payload with the signer.