pub enum BlockSignerStartError {
Local(Error),
Remote(RemoteSignerStartError),
}Expand description
Errors that can occur when starting a block signer.
Variants
Local(Error)
An error that can occur when signing a block with a local signer.
Remote(RemoteSignerStartError)
An error that can occur when signing a block with a remote signer.