pub enum SyncStartError {
RpcError(RpcError<TransportErrorKind>),
FromBlock(FromBlockError),
BlockNotFound(BlockId),
InvalidL1GenesisHash(B256, B256),
InvalidL2GenesisHash(B256, B256),
MismatchedFinalizedBlock(B256, B256),
L1OriginMismatch,
NonZeroSequenceNumber,
InconsistentSequenceNumber,
}Expand description
An error that can occur during the sync start process.
Variants
RpcError(RpcError<TransportErrorKind>)
An rpc error occurred
FromBlock(FromBlockError)
An error occurred while converting a block to L2BlockInfo.
BlockNotFound(BlockId)
A block could not be found.
InvalidL1GenesisHash(B256, B256)
Invalid L1 genesis hash.
InvalidL2GenesisHash(B256, B256)
Invalid L2 genesis hash.
MismatchedFinalizedBlock(B256, B256)
Finalized block mismatch
L1OriginMismatch
L1 origin mismatch.
NonZeroSequenceNumber
Non-zero sequence number.
InconsistentSequenceNumber
Inconsistent sequence number.