pub struct RemoteSignerHandler { /* private fields */ }Expand description
Remote signer that communicates with an external signing service via JSON-RPC
Implementations
Sourceimpl RemoteSignerHandler
impl RemoteSignerHandler
Sourcepub const fn is_certificate_watching_enabled(&self) -> bool
pub const fn is_certificate_watching_enabled(&self) -> bool
Returns true if certificate watching is enabled
Sourcepub async fn sign_block_v1(
&self,
payload_hash: PayloadHash,
chain_id: ChainId,
sender_address: Address,
) -> Result<Signature, RemoteSignerError>
pub async fn sign_block_v1( &self, payload_hash: PayloadHash, chain_id: ChainId, sender_address: Address, ) -> Result<Signature, RemoteSignerError>
Signs a block payload hash using the remote signer via JSON-RPC