pub struct RuntimeLoader {
pub provider: AlloyChainProvider,
pub config: Arc<RollupConfig>,
pub cache: LruCache<BlockInfo, RuntimeConfig>,
/* private fields */
}Expand description
The runtime loader.
Fields
provider: AlloyChainProviderThe L1 Client
config: Arc<RollupConfig>The rollup config.
cache: LruCache<BlockInfo, RuntimeConfig>Cache mapping BlockInfo to the RuntimeConfig.
If the block hash for the given block info is a mismatch, the runtime config will be reloaded.
Implementations
Sourceimpl RuntimeLoader
impl RuntimeLoader
Sourcepub fn new(l1_eth_rpc: Url, config: Arc<RollupConfig>) -> Self
pub fn new(l1_eth_rpc: Url, config: Arc<RollupConfig>) -> Self
Constructs a new RuntimeLoader with the given provider Url.
Sourcepub async fn load_latest(&mut self) -> Result<RuntimeConfig, RuntimeLoaderError>
pub async fn load_latest(&mut self) -> Result<RuntimeConfig, RuntimeLoaderError>
Loads the RuntimeConfig for the latest block.
Sourcepub async fn load(
&mut self,
block_info: BlockInfo,
) -> Result<RuntimeConfig, RuntimeLoaderError>
pub async fn load( &mut self, block_info: BlockInfo, ) -> Result<RuntimeConfig, RuntimeLoaderError>
Loads the RuntimeConfig for the given BlockInfo.