Structs
- Client
Cert - Client certificate and key pair for mTLS authentication (PEM format)
- L2Forkchoice
State - An unsafe, safe, and finalized L2BlockInfo returned by the crate::find_starting_forkchoice function.
- Metrics
- Container for metrics.
- Remote
Signer - Configuration for the remote signer client
- Remote
Signer Handler - Remote signer that communicates with an external signing service via JSON-RPC
- Runtime
Config - The runtime config.
- Runtime
Loader - The runtime loader.
Enums
- Block
Signer - A builder for a block signer.
- Block
Signer Error - Errors that can occur when signing a block.
- Block
Signer Handler - A handler for a block signer.
- Block
Signer Start Error - Errors that can occur when starting a block signer.
- Certificate
Error - Errors that can occur when handling certificates
- Remote
Signer Error - Errors that can occur when using the remote signer
- Remote
Signer Start Error - Errors that can occur when starting a remote signer.
- Runtime
Loader Error - Error type for the runtime loader.
- Sync
Start Error - An error that can occur during the sync start process.
Functions
- find_
starting_ forkchoice - Searches for the latest
L2ForkchoiceStatethat we can use to start the sync process with.